@@ -5,7 +5,7 @@ rescue LoadError
 end
 
 if defined?(Curl)
-  WebMock::VersionChecker.new('Curb', Curl::CURB_VERSION, '0.7.16', '0.8.7').check_version!
+  WebMock::VersionChecker.new('Curb', Curl::CURB_VERSION, '0.7.16', '0.9.1', ['0.8.7']).check_version!
 
   module WebMock
     module HttpLibAdapters
@@ -62,7 +62,7 @@ if defined?(Curl)
         if webmock_response = WebMock::StubRegistry.instance.response_for_request(request_signature)
           build_curb_response(webmock_response)
           WebMock::CallbackRegistry.invoke_callbacks(
-            {:lib => :curb}, request_signature, webmock_response)
+            {lib: :curb}, request_signature, webmock_response)
           invoke_curb_callbacks
           true
         elsif WebMock.net_connect_allowed?(request_signature.uri)
@@ -70,7 +70,7 @@ if defined?(Curl)
           if WebMock::CallbackRegistry.any_callbacks?
             webmock_response = build_webmock_response
             WebMock::CallbackRegistry.invoke_callbacks(
-              {:lib => :curb, :real_request => true}, request_signature,
+              {lib: :curb, real_request: true}, request_signature,
                 webmock_response)
           end
           res
@@ -84,11 +84,11 @@ if defined?(Curl)
 
         uri = WebMock::Util::URI.heuristic_parse(self.url)
         uri.path = uri.normalized_path.gsub("[^:]//","/")
-        uri.user = self.username
-        uri.password = self.password
+
+        headers = headers_as_hash(self.headers).merge(basic_auth_headers)
 
         request_body = case method
-        when :post
+        when :post, :patch
           self.post_body || @post_body
         when :put
           @put_data
@@ -96,15 +96,56 @@ if defined?(Curl)
           nil
         end
 
+        if defined?( @on_debug )
+          @on_debug.call("Trying 127.0.0.1...\r\n", 0)
+          @on_debug.call('Connected to ' + uri.hostname + "\r\n", 0)
+          @debug_method = method.upcase
+          @debug_path = uri.path
+          @debug_host = uri.hostname
+          http_request = ["#{@debug_method} #{@debug_path} HTTP/1.1"]
+          http_request << "Host: #{uri.hostname}"
+          headers.each do |name, value|
+            http_request << "#{name}: #{value}"
+          end
+          @on_debug.call(http_request.join("\r\n") + "\r\n\r\n", 2)
+          if request_body
+            @on_debug.call(request_body + "\r\n", 4)
+            @on_debug.call(
+              "upload completely sent off: #{request_body.bytesize}"\
+              " out of #{request_body.bytesize} bytes\r\n", 0
+            )
+          end
+        end
+
         request_signature = WebMock::RequestSignature.new(
           method,
           uri.to_s,
-          :body => request_body,
-          :headers => self.headers
+          body: request_body,
+          headers: headers
         )
         request_signature
       end
 
+      def headers_as_hash(headers)
+        if headers.is_a?(Array)
+          headers.inject({}) {|hash, header|
+            name, value = header.split(":").map(&:strip)
+            hash[name] = value
+            hash
+          }
+        else
+          headers
+        end
+      end
+
+      def basic_auth_headers
+        if self.username
+          {'Authorization' => WebMock::Util::Headers.basic_auth_header(self.username, self.password)}
+        else
+          {}
+        end
+      end
+
       def build_curb_response(webmock_response)
         raise Curl::Err::TimeoutError if webmock_response.should_timeout
         webmock_response.raise_error_if_any
@@ -113,10 +154,16 @@ if defined?(Curl)
         @response_code = webmock_response.status[0]
 
         @header_str = "HTTP/1.1 #{webmock_response.status[0]} #{webmock_response.status[1]}\r\n"
+
+        @on_debug.call(@header_str, 1) if defined?( @on_debug )
+
         if webmock_response.headers
           @header_str << webmock_response.headers.map do |k,v|
-            "#{k}: #{v.is_a?(Array) ? v.join(", ") : v}"
+            header = "#{k}: #{v.is_a?(Array) ? v.join(", ") : v}"
+            @on_debug.call(header + "\r\n", 1) if defined?( @on_debug )
+            header
           end.join("\r\n")
+          @on_debug.call("\r\n", 1) if defined?( @on_debug )
 
           location = webmock_response.headers['Location']
           if self.follow_location? && location
@@ -174,6 +221,16 @@ if defined?(Curl)
         status, headers =
          WebMock::HttpLibAdapters::CurbAdapter.parse_header_string(self.header_str)
 
+        if defined?( @on_debug )
+          http_response = ["HTTP/1.0 #{@debug_method} #{@debug_path}"]
+          headers.each do |name, value|
+            http_response << "#{name}: #{value}"
+          end
+          http_response << self.body_str
+          @on_debug.call(http_response.join("\r\n") + "\r\n", 3)
+          @on_debug.call("Connection #0 to host #{@debug_host} left intact\r\n", 0)
+        end
+
         webmock_response = WebMock::Response.new
         webmock_response.status = [self.response_code, status]
         webmock_response.body = self.body_str
@@ -237,6 +294,14 @@ if defined?(Curl)
         super
       end
 
+      def verbose=(verbose)
+        @verbose = verbose
+      end
+
+      def verbose?
+        @verbose ||= false
+      end
+
       def body_str
         @body_str ||= super
       end
@@ -259,7 +324,7 @@ if defined?(Curl)
         @content_type ||= super
       end
 
-      %w[ success failure missing header body complete progress ].each do |callback|
+      %w[ success failure missing header body complete progress debug ].each do |callback|
         class_eval <<-METHOD, __FILE__, __LINE__
           def on_#{callback} &block
             @on_#{callback} = block
