@@ -79,7 +79,7 @@ module WebMock
           if webmock_response = WebMock::StubRegistry.instance.response_for_request(request_signature)
             @socket = Net::HTTP.socket_type.new
             WebMock::CallbackRegistry.invoke_callbacks(
-              {:lib => :net_http}, request_signature, webmock_response)
+              {lib: :net_http}, request_signature, webmock_response)
             build_net_http_response(webmock_response, &block)
           elsif WebMock.net_connect_allowed?(request_signature.uri)
             check_right_http_connection
@@ -87,7 +87,7 @@ module WebMock
               if WebMock::CallbackRegistry.any_callbacks?
                 webmock_response = build_webmock_response(response)
                 WebMock::CallbackRegistry.invoke_callbacks(
-                  {:lib => :net_http, :real_request => true}, request_signature, webmock_response)
+                  {lib: :net_http, real_request: true}, request_signature, webmock_response)
               end
               response.extend Net::WebMockHTTPResponse
               block.call response if block
@@ -168,7 +168,9 @@ module WebMock
 
           response.extend Net::WebMockHTTPResponse
 
-          raise Timeout::Error, "execution expired" if webmock_response.should_timeout
+          if webmock_response.should_timeout
+            raise timeout_exception, "execution expired"
+          end
 
           webmock_response.raise_error_if_any
 
@@ -177,6 +179,16 @@ module WebMock
           response
         end
 
+        def timeout_exception
+          if defined?(Net::OpenTimeout)
+            # Ruby 2.x
+            Net::OpenTimeout
+          else
+            # Fallback, if things change
+            Timeout::Error
+          end
+        end
+
         def build_webmock_response(net_http_response)
           webmock_response = WebMock::Response.new
           webmock_response.status = [
@@ -233,6 +245,9 @@ class StubSocket #:nodoc:
     @closed ||= true
   end
 
+  def close
+  end
+
   def readuntil(*args)
   end
 
@@ -241,8 +256,8 @@ end
 module Net  #:nodoc: all
 
   class WebMockNetBufferedIO < BufferedIO
-    def initialize(io, debug_output = nil)
-      @read_timeout = 60
+    def initialize(io, read_timeout: 60, continue_timeout: nil, debug_output: nil)
+      @read_timeout = read_timeout
       @rbuf = ''
       @debug_output = debug_output
 
@@ -275,19 +290,11 @@ module WebMock
 
       path = WebMock::Util::URI.heuristic_parse(path).request_uri if path =~ /^http/
 
-      if request["authorization"] =~ /^Basic /
-        userinfo = WebMock::Util::Headers.decode_userinfo_from_header(request["authorization"])
-        userinfo = WebMock::Util::URI.encode_unsafe_chars_in_userinfo(userinfo) + "@"
-      else
-        userinfo = ""
-      end
-
-      uri = "#{protocol}://#{userinfo}#{net_http.address}:#{net_http.port}#{path}"
+      uri = "#{protocol}://#{net_http.address}:#{net_http.port}#{path}"
       method = request.method.downcase.to_sym
 
       headers = Hash[*request.to_hash.map {|k,v| [k, v]}.inject([]) {|r,x| r + x}]
       validate_headers(headers)
-      headers.reject! {|k,v| k =~ /[Aa]uthorization/ && v.first =~ /^Basic / } #we added it to url userinfo
 
       if request.body_stream
         body = request.body_stream.read
@@ -300,11 +307,12 @@ module WebMock
         request.set_body_internal body
       end
 
-      WebMock::RequestSignature.new(method, uri, :body => request.body, :headers => headers)
+      WebMock::RequestSignature.new(method, uri, body: request.body, headers: headers)
     end
 
     def self.validate_headers(headers)
-      # If you make a request with headers that are symbols Net::HTTP raises a NoMethodError
+      # For Ruby versions < 2.3.0, if you make a request with headers that are symbols
+      # Net::HTTP raises a NoMethodError
       #
       # WebMock normalizes headers when creating a RequestSignature,
       # and will update all headers from symbols to strings.
@@ -313,9 +321,11 @@ module WebMock
       #
       # So before this point, WebMock raises an ArgumentError if any of the headers are symbols
       # instead of the cryptic NoMethodError "undefined method `split' ...` from Net::HTTP
-      header_as_symbol = headers.keys.find {|header| header.is_a? Symbol}
-      if header_as_symbol
-        raise ArgumentError.new("Net:HTTP does not accept headers as symbols")
+      if Gem::Version.new(RUBY_VERSION.dup) < Gem::Version.new('2.3.0')
+        header_as_symbol = headers.keys.find {|header| header.is_a? Symbol}
+        if header_as_symbol
+          raise ArgumentError.new("Net:HTTP does not accept headers as symbols")
+        end
       end
     end
 
