@@ -49,13 +49,28 @@ module WebMock
 
 
     def assign_options(options)
-      options = WebMock::Util::HashKeysStringifier.stringify_keys!(options, :deep => true)
-      HashValidator.new(options).validate_keys('body', 'headers', 'query')
+      options = WebMock::Util::HashKeysStringifier.stringify_keys!(options, deep: true)
+      HashValidator.new(options).validate_keys('body', 'headers', 'query', 'basic_auth')
+      set_basic_auth_as_headers!(options)
       @body_pattern = BodyPattern.new(options['body']) if options.has_key?('body')
       @headers_pattern = HeadersPattern.new(options['headers']) if options.has_key?('headers')
       @uri_pattern.add_query_params(options['query']) if options.has_key?('query')
     end
 
+    def set_basic_auth_as_headers!(options)
+      if basic_auth = options.delete('basic_auth')
+        validate_basic_auth!(basic_auth)
+        options['headers'] ||= {}
+        options['headers']['Authorization'] = WebMock::Util::Headers.basic_auth_header(basic_auth[0],basic_auth[1])
+      end
+    end
+
+    def validate_basic_auth!(basic_auth)
+      if !basic_auth.is_a?(Array) || basic_auth.map{|e| e.is_a?(String)}.uniq != [true]
+        raise "The basic_auth option value should be an array which contains 2 strings: username and password"
+      end
+    end
+
     def create_uri_pattern(uri)
       if uri.is_a?(Regexp)
         URIRegexpPattern.new(uri)
@@ -105,7 +120,7 @@ module WebMock
       elsif rSpecHashIncludingMatcher?(query_params)
         WebMock::Matchers::HashIncludingMatcher.from_rspec_matcher(query_params)
       else
-        WebMock::Util::QueryMapper.query_to_values(query_params, :notation => Config.instance.query_values_notation)
+        WebMock::Util::QueryMapper.query_to_values(query_params, notation: Config.instance.query_values_notation)
       end
     end
 
@@ -119,7 +134,7 @@ module WebMock
   class URIRegexpPattern  < URIPattern
     def matches?(uri)
       WebMock::Util::URI.variations_of_uri_as_strings(uri).any? { |u| u.match(@pattern) } &&
-        (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query, :notation => Config.instance.query_values_notation))
+        (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query, notation: Config.instance.query_values_notation))
     end
 
     def to_s
@@ -158,7 +173,7 @@ module WebMock
       if @pattern.is_a?(Addressable::URI)
         if @query_params
           uri.omit(:query) === @pattern &&
-          (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query, :notation => Config.instance.query_values_notation))
+          (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query, notation: Config.instance.query_values_notation))
         else
           uri === @pattern
         end
@@ -170,8 +185,8 @@ module WebMock
     def add_query_params(query_params)
       super
       if @query_params.is_a?(Hash) || @query_params.is_a?(String)
-        query_hash = (WebMock::Util::QueryMapper.query_to_values(@pattern.query, :notation => Config.instance.query_values_notation) || {}).merge(@query_params)
-        @pattern.query = WebMock::Util::QueryMapper.values_to_query(query_hash, :notation => WebMock::Config.instance.query_values_notation)
+        query_hash = (WebMock::Util::QueryMapper.query_to_values(@pattern.query, notation: Config.instance.query_values_notation) || {}).merge(@query_params)
+        @pattern.query = WebMock::Util::QueryMapper.values_to_query(query_hash, notation: WebMock::Config.instance.query_values_notation)
         @query_params = nil
       end
     end
@@ -213,6 +228,8 @@ module WebMock
     end
 
     def matches?(body, content_type = "")
+      assert_non_multipart_body(content_type)
+
       if (@pattern).is_a?(Hash)
         return true if @pattern.empty?
         matching_hashes?(body_as_hash(body, content_type), @pattern)
@@ -237,7 +254,13 @@ module WebMock
       when :xml then
         Crack::XML.parse(body)
       else
-        WebMock::Util::QueryMapper.query_to_values(body, :notation => Config.instance.query_values_notation)
+        WebMock::Util::QueryMapper.query_to_values(body, notation: Config.instance.query_values_notation)
+      end
+    end
+
+    def assert_non_multipart_body(content_type)
+      if content_type =~ %r{^multipart/form-data}
+        raise ArgumentError.new("WebMock does not support matching body for multipart/form-data requests yet :(")
       end
     end
 
@@ -284,7 +307,7 @@ module WebMock
     end
 
     def normalize_hash(hash)
-      Hash[WebMock::Util::HashKeysStringifier.stringify_keys!(hash, :deep => true).sort]
+      Hash[WebMock::Util::HashKeysStringifier.stringify_keys!(hash, deep: true).sort]
     end
 
   end
