@@ -1,3 +1,5 @@
+require 'base64'
+
 module WebMock
 
   module Util
@@ -36,6 +38,10 @@ module WebMock
         header.sub(/^Basic /, "").unpack("m").first
       end
 
+      def self.basic_auth_header(*credentials)
+        "Basic #{Base64.strict_encode64(credentials.join(':')).chomp}"
+      end
+
     end
 
   end
