@@ -11,8 +11,8 @@ unless RUBY_PLATFORM =~ /java/
 
     describe "when doing PUTs" do
       it "should stub them" do
-        stub_request(:put, "www.example.com").with(:body => "01234")
-        expect(http_request(:put, "http://www.example.com", :body => "01234").
+        stub_request(:put, "www.example.com").with(body: "01234")
+        expect(http_request(:put, "http://www.example.com", body: "01234").
           status).to eq("200")
       end
     end
@@ -30,9 +30,26 @@ unless RUBY_PLATFORM =~ /java/
         @curl.url = "http://example.com"
       end
 
+      describe 'on_debug' do
+        it "should call on_debug" do
+          stub_request(:any, "example.com").
+            to_return(status: 200, headers: { 'Server' => 'nginx' }, body: { hello: :world }.to_json)
+
+          test = []
+
+          @curl.on_debug do |message, operation|
+            test << "#{operation} -> #{message}"
+          end
+          @curl.headers['Content-Type'] = 'application/json'
+          @curl.http_post({ hello: :world }.to_json)
+
+          expect(test).to_not be_empty
+        end
+      end
+
       it "should call on_success with 2xx response" do
         body = "on_success fired"
-        stub_request(:any, "example.com").to_return(:body => body)
+        stub_request(:any, "example.com").to_return(body: body)
 
         test = nil
         @curl.on_success do |c|
@@ -45,7 +62,7 @@ unless RUBY_PLATFORM =~ /java/
       it "should call on_missing with 4xx response" do
         response_code = 403
         stub_request(:any, "example.com").
-          to_return(:status => [response_code, "None shall pass"])
+          to_return(status: [response_code, "None shall pass"])
 
         test = nil
         @curl.on_missing do |c, code|
@@ -58,7 +75,7 @@ unless RUBY_PLATFORM =~ /java/
       it "should call on_failure with 5xx response" do
         response_code = 599
         stub_request(:any, "example.com").
-          to_return(:status => [response_code, "Server On Fire"])
+          to_return(status: [response_code, "Server On Fire"])
 
         test = nil
         @curl.on_failure do |c, code|
@@ -71,7 +88,7 @@ unless RUBY_PLATFORM =~ /java/
       it "should call on_body when response body is read" do
         body = "on_body fired"
         stub_request(:any, "example.com").
-          to_return(:body => body)
+          to_return(body: body)
 
         test = nil
         @curl.on_body do |data|
@@ -83,8 +100,8 @@ unless RUBY_PLATFORM =~ /java/
 
       it "should call on_body for each chunk with chunked response" do
         stub_request(:any, "example.com").
-          to_return(:body => ["first_chunk", "second_chunk"],
-                    :headers => {"Transfer-Encoding" => "chunked"})
+          to_return(body: ["first_chunk", "second_chunk"],
+                    headers: {"Transfer-Encoding" => "chunked"})
 
         test = []
         @curl.on_body do |data|
@@ -96,7 +113,7 @@ unless RUBY_PLATFORM =~ /java/
 
       it "should call on_header when response headers are read" do
         stub_request(:any, "example.com").
-          to_return(:headers => {:one => 1})
+          to_return(headers: {one: 1})
 
         test = []
         @curl.on_header do |data|
@@ -111,7 +128,7 @@ unless RUBY_PLATFORM =~ /java/
 
       it "should call on_complete when request is complete" do
         body = "on_complete fired"
-        stub_request(:any, "example.com").to_return(:body => body)
+        stub_request(:any, "example.com").to_return(body: body)
 
         test = nil
         @curl.on_complete do |curl|
@@ -122,7 +139,7 @@ unless RUBY_PLATFORM =~ /java/
       end
 
       it "should call on_progress when portion of response body is read" do
-        stub_request(:any, "example.com").to_return(:body => "01234")
+        stub_request(:any, "example.com").to_return(body: "01234")
 
         test = nil
         @curl.on_progress do |*args|
@@ -150,7 +167,7 @@ unless RUBY_PLATFORM =~ /java/
       end
 
       it "should call callbacks in correct order on failed request" do
-        stub_request(:any, "example.com").to_return(:status => [500, ""])
+        stub_request(:any, "example.com").to_return(status: [500, ""])
         order = []
         @curl.on_success {|*args| order << :on_success }
         @curl.on_missing {|*args| order << :on_missing }
@@ -165,7 +182,7 @@ unless RUBY_PLATFORM =~ /java/
       end
 
       it "should call callbacks in correct order on missing request" do
-        stub_request(:any, "example.com").to_return(:status => [403, ""])
+        stub_request(:any, "example.com").to_return(status: [403, ""])
         order = []
         @curl.on_success {|*args| order << :on_success }
         @curl.on_missing {|*args| order << :on_missing }
@@ -191,9 +208,9 @@ unless RUBY_PLATFORM =~ /java/
 
         it 'should be the same as #url even with a location header' do
           stub_request(:any, 'example.com').
-            to_return(:body    => "abc",
-                      :status  => 302,
-                      :headers => { 'Location' => 'http://www.example.com' })
+            to_return(body: "abc",
+                      status: 302,
+                      headers: { 'Location' => 'http://www.example.com' })
 
           @curl.http_get
           expect(@curl.last_effective_url).to eq('http://example.com')
@@ -211,7 +228,7 @@ unless RUBY_PLATFORM =~ /java/
 
         it 'should be the value of the location header when present' do
           stub_request(:any, 'example.com').
-            to_return(:headers => { 'Location' => 'http://www.example.com' })
+            to_return(headers: { 'Location' => 'http://www.example.com' })
           stub_request(:any, 'www.example.com')
 
           @curl.http_get
@@ -220,9 +237,9 @@ unless RUBY_PLATFORM =~ /java/
 
         it 'should work with more than one redirect' do
           stub_request(:any, 'example.com').
-            to_return(:headers => { 'Location' => 'http://www.example.com' })
+            to_return(headers: { 'Location' => 'http://www.example.com' })
           stub_request(:any, 'www.example.com').
-            to_return(:headers => { 'Location' => 'http://blog.example.com' })
+            to_return(headers: { 'Location' => 'http://blog.example.com' })
           stub_request(:any, 'blog.example.com')
 
           @curl.http_get
@@ -231,7 +248,7 @@ unless RUBY_PLATFORM =~ /java/
 
         it 'should maintain the original url' do
           stub_request(:any, 'example.com').
-            to_return(:headers => { 'Location' => 'http://www.example.com' })
+            to_return(headers: { 'Location' => 'http://www.example.com' })
           stub_request(:any, 'www.example.com')
 
           @curl.http_get
@@ -240,10 +257,10 @@ unless RUBY_PLATFORM =~ /java/
 
         it 'should have the redirected-to attrs (body, response code)' do
           stub_request(:any, 'example.com').
-            to_return(:body => 'request A',
-                      :status => 302,
-                      :headers => { 'Location' => 'http://www.example.com' })
-          stub_request(:any, 'www.example.com').to_return(:body => 'request B')
+            to_return(body: 'request A',
+                      status: 302,
+                      headers: { 'Location' => 'http://www.example.com' })
+          stub_request(:any, 'www.example.com').to_return(body: 'request B')
 
           @curl.http_get
           expect(@curl.body_str).to eq('request B')
@@ -252,10 +269,10 @@ unless RUBY_PLATFORM =~ /java/
 
         it 'should follow more than one redirect' do
           stub_request(:any, 'example.com').
-            to_return(:headers => { 'Location' => 'http://www.example.com' })
+            to_return(headers: { 'Location' => 'http://www.example.com' })
           stub_request(:any, 'www.example.com').
-            to_return(:headers => { 'Location' => 'http://blog.example.com' })
-          stub_request(:any, 'blog.example.com').to_return(:body => 'blog post')
+            to_return(headers: { 'Location' => 'http://blog.example.com' })
+          stub_request(:any, 'blog.example.com').to_return(body: 'blog post')
 
           @curl.http_get
           expect(@curl.url).to eq('http://example.com')
@@ -275,9 +292,9 @@ unless RUBY_PLATFORM =~ /java/
           content_type = "application/json"
 
           stub_request(:any, 'example.com').
-            to_return(:body     => "abc",
-                      :status   => 200,
-                      :headers  => { 'Content-Type' => content_type })
+            to_return(body: "abc",
+                      status: 200,
+                      headers: { 'Content-Type' => content_type })
 
           @curl.http_get
           expect(@curl.content_type).to eq(content_type)
@@ -288,8 +305,8 @@ unless RUBY_PLATFORM =~ /java/
         it "returns nil for content_type" do
 
           stub_request(:any, 'example.com').
-            to_return(:body     => "abc",
-                      :status   => 200 )
+            to_return(body: "abc",
+                      status: 200 )
 
           @curl.http_get
           expect(@curl.content_type).to be_nil
@@ -305,9 +322,9 @@ unless RUBY_PLATFORM =~ /java/
 
       it "is true when Transfer-Encoding is 'chunked' and body responds to each" do
         stub_request(:any, 'example.com').
-          to_return(:body     => ["abc", "def"],
-                    :status   => 200,
-                    :headers  => { 'Transfer-Encoding' => 'chunked' })
+          to_return(body: ["abc", "def"],
+                    status: 200,
+                    headers: { 'Transfer-Encoding' => 'chunked' })
 
         @curl.http_get
         expect(@curl).to be_chunked_response
@@ -315,8 +332,8 @@ unless RUBY_PLATFORM =~ /java/
 
       it "is false when Transfer-Encoding is not 'chunked'" do
         stub_request(:any, 'example.com').
-          to_return(:body     => ["abc", "def"],
-                    :status   => 200)
+          to_return(body: ["abc", "def"],
+                    status: 200)
 
         @curl.http_get
         expect(@curl).not_to be_chunked_response
@@ -324,8 +341,8 @@ unless RUBY_PLATFORM =~ /java/
 
       it "is false when Transfer-Encoding is 'chunked' but body does not respond to each" do
         stub_request(:any, 'example.com').
-          to_return(:body     => "abc",
-                    :status   => 200)
+          to_return(body: "abc",
+                    status: 200)
 
         @curl.http_get
         expect(@curl).not_to be_chunked_response
@@ -339,7 +356,7 @@ unless RUBY_PLATFORM =~ /java/
       include CurbSpecHelper::DynamicHttp
 
       it "should work with uppercase arguments" do
-        stub_request(:get, "www.example.com").to_return(:body => "abc")
+        stub_request(:get, "www.example.com").to_return(body: "abc")
 
         c = Curl::Easy.new
         c.url = "http://www.example.com"
@@ -348,13 +365,46 @@ unless RUBY_PLATFORM =~ /java/
       end
 
       it "should alias body to body_str" do
-        stub_request(:get, "www.example.com").to_return(:body => "abc")
+        stub_request(:get, "www.example.com").to_return(body: "abc")
 
         c = Curl::Easy.new
         c.url = "http://www.example.com"
         c.http(:GET)
         expect(c.body).to eq("abc")
       end
+
+      it "supports array headers passed to Curl::Easy" do
+        stub_request(:get, "www.example.com").with(headers: {'X-One' => '1'}).to_return(body: "abc")
+
+        c = Curl::Easy.new
+        c.url = "http://www.example.com"
+        c.headers = ["X-One: 1"]
+        c.http(:GET)
+        expect(c.body).to eq("abc")
+      end
+
+      describe 'match request body' do
+        it 'for post' do
+          stub_request(:post, "www.example.com").with(body: 'foo=nhe').to_return(body: "abc")
+
+          response = Curl.post("http://www.example.com", {foo: :nhe})
+          expect(response.body_str).to eq("abc")
+        end
+
+        it 'for patch' do
+          stub_request(:patch, "www.example.com").with(body: 'foo=nhe').to_return(body: "abc")
+
+          response = Curl.patch("http://www.example.com", {foo: :nhe})
+          expect(response.body_str).to eq("abc")
+        end
+
+        it 'for put' do
+          stub_request(:put, "www.example.com").with(body: 'foo=nhe').to_return(body: "abc")
+
+          response = Curl.put("http://www.example.com", {foo: :nhe})
+          expect(response.body_str).to eq("abc")
+        end
+      end
     end
 
     describe "using #http_* methods for requests" do
@@ -362,7 +412,7 @@ unless RUBY_PLATFORM =~ /java/
       include CurbSpecHelper::NamedHttp
 
       it "should work with blank arguments for post" do
-        stub_request(:post, "www.example.com").with(:body => "01234")
+        stub_request(:post, "www.example.com").with(body: "01234")
         c = Curl::Easy.new
         c.url = "http://www.example.com"
         c.post_body = "01234"
@@ -371,13 +421,13 @@ unless RUBY_PLATFORM =~ /java/
       end
 
       it "should work with several body arguments for post using the class method" do
-        stub_request(:post, "www.example.com").with(:body => {:user => {:first_name=>'Bartosz', :last_name=>'Blimke'}})
+        stub_request(:post, "www.example.com").with(body: {user: {first_name: 'Bartosz', last_name: 'Blimke'}})
         c = Curl::Easy.http_post "http://www.example.com", 'user[first_name]=Bartosz', 'user[last_name]=Blimke'
         expect(c.response_code).to eq(200)
       end
 
       it "should work with blank arguments for put" do
-        stub_request(:put, "www.example.com").with(:body => "01234")
+        stub_request(:put, "www.example.com").with(body: "01234")
         c = Curl::Easy.new
         c.url = "http://www.example.com"
         c.put_data = "01234"
@@ -386,9 +436,9 @@ unless RUBY_PLATFORM =~ /java/
       end
 
       it "should work with multiple arguments for post" do
-        data = { :name => "john", :address => "111 example ave" }
+        data = { name: "john", address: "111 example ave" }
 
-        stub_request(:post, "www.example.com").with(:body => data)
+        stub_request(:post, "www.example.com").with(body: data)
         c = Curl::Easy.new
         c.url = "http://www.example.com"
         c.http_post Curl::PostField.content('name', data[:name]),  Curl::PostField.content('address', data[:address])
