@@ -8,6 +8,9 @@ module EMHttpRequestSpecHelper
   def http_request(method, uri, options = {}, &block)
     @http = nil
     head = options[:headers] || {}
+    if options[:basic_auth]
+      head.merge!('authorization' => options[:basic_auth])
+    end
     response = nil
     error = nil
     error_set = false
@@ -15,11 +18,12 @@ module EMHttpRequestSpecHelper
     EventMachine.run {
       request = EventMachine::HttpRequest.new("#{uri.normalize.to_s}")
       http = request.send(method, {
-        :timeout => 30,
-        :body => options[:body],
-        :file => options[:file],
-        :query => options[:query],
-        :head => head.merge('authorization' => [uri.user, uri.password])
+        timeout: 30,
+        body: options[:body],
+        file: options[:file],
+        query: options[:query],
+        head: head,
+        compressed: false
       }, &block)
       http.errback {
         error_set = true
@@ -32,10 +36,10 @@ module EMHttpRequestSpecHelper
       }
       http.callback {
         response = OpenStruct.new({
-          :body => http.response,
-          :headers => WebMock::Util::Headers.normalize_headers(extract_response_headers(http)),
-          :message => http.response_header.http_reason,
-          :status => http.response_header.status.to_s
+          body: http.response,
+          headers: WebMock::Util::Headers.normalize_headers(extract_response_headers(http)),
+          message: http.response_header.http_reason,
+          status: http.response_header.status.to_s
         })
         EventMachine.stop
       }
