@@ -19,7 +19,7 @@ describe "HTTP.rb" do
 
     it "fails if body was already streamed" do
       response.body.to_s
-      expect { response.body.readpartial 1 }.to raise_error
+      expect { response.body.readpartial 1 }.to raise_error(HTTP::StateError)
     end
   end
 
@@ -36,7 +36,7 @@ describe "HTTP.rb" do
   end
 
   context "following redirects" do
-    let(:options)  { { :follow => true } }
+    let(:options)  { { follow: true } }
     let(:response) { http_request(:get, "http://example.com", options) }
     let(:headers)  { response.headers }
 
