@@ -1,17 +1,17 @@
 shared_examples_for "Net::HTTP" do
-  describe "when making real requests", :net_connect => true do
+  describe "when making real requests", net_connect: true do
     let(:port){ WebMockServer.instance.port }
 
     before(:each) do
       @http = Net::HTTP.new("localhost", port)
     end
 
-    it "should return a Net::ReadAdapter from response.body when a real request is made with a block and #read_body", :net_connect => true do
+    it "should return a Net::ReadAdapter from response.body when a real request is made with a block and #read_body", net_connect: true do
       response = Net::HTTP.new("localhost", port).request_get('/') { |r| r.read_body { } }
       expect(response.body).to be_a(Net::ReadAdapter)
     end
 
-    it "should handle requests with block passed to read_body", :net_connect => true do
+    it "should handle requests with block passed to read_body", net_connect: true do
       body = ""
       req = Net::HTTP::Get.new("/")
       Net::HTTP.start("localhost", port) do |http|
@@ -24,7 +24,7 @@ shared_examples_for "Net::HTTP" do
       expect(body).to match(/hello world/)
     end
 
-    it "should connect only once when connected on start", :net_connect => true do
+    it "should connect only once when connected on start", net_connect: true do
       @http = Net::HTTP.new('localhost', port)
       socket_id_before_request = socket_id_after_request = nil
       @http.start {|conn|
@@ -43,6 +43,17 @@ shared_examples_for "Net::HTTP" do
       end
     end
 
+    it "should pass the read_timeout value on", net_connect: true do
+      @http = Net::HTTP.new('localhost', port)
+      read_timeout = @http.read_timeout + 1
+      @http.read_timeout = read_timeout
+      @http.start {|conn|
+        conn.request(Net::HTTP::Get.new("/"))
+        socket = conn.instance_variable_get(:@socket)
+        expect(socket.read_timeout).to eq(read_timeout)
+      }
+    end
+
     describe "without start" do
       it "should close connection after a real request" do
         @http.get('/') { }
