@@ -5,9 +5,12 @@ module PatronSpecHelper
     method = method.to_sym
     uri = Addressable::URI.heuristic_parse(uri)
     sess = Patron::Session.new
-    sess.base_url = "#{uri.omit(:userinfo, :path, :query).normalize.to_s}".gsub(/\/$/,"")
-    sess.username = uri.user
-    sess.password = uri.password
+    sess.base_url = "#{uri.omit(:path, :query).normalize.to_s}".gsub(/\/$/,"")
+
+    if options[:basic_auth]
+      sess.username = options[:basic_auth][0]
+      sess.password = options[:basic_auth][1]
+    end
 
     sess.connect_timeout = 30
     sess.timeout = 30
@@ -15,7 +18,7 @@ module PatronSpecHelper
     uri = "#{uri.path}#{uri.query ? '?' : ''}#{uri.query}"
     uri.gsub!(' ','%20')
     response = sess.request(method, uri, options[:headers] || {}, {
-      :data => options[:body]
+      data: options[:body]
     })
     headers = {}
     if response.headers
@@ -29,10 +32,10 @@ module PatronSpecHelper
     message = response.status_line.match(status_line_pattern)[3] || ""
 
     OpenStruct.new({
-      :body => response.body,
-      :headers => WebMock::Util::Headers.normalize_headers(headers),
-      :status => response.status.to_s,
-      :message => message
+      body: response.body,
+      headers: WebMock::Util::Headers.normalize_headers(headers),
+      status: response.status.to_s,
+      message: message
     })
   end
 
