@@ -4,29 +4,29 @@ shared_examples_for "stubbing requests" do |*adapter_info|
   describe "when requests are stubbed" do
     describe "based on uri" do
       it "should return stubbed response even if request have escaped parameters" do
-        stub_request(:get, "www.example.com/hello+/?#{NOT_ESCAPED_PARAMS}").to_return(:body => "abc")
+        stub_request(:get, "www.example.com/hello+/?#{NOT_ESCAPED_PARAMS}").to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/hello%2B/?#{ESCAPED_PARAMS}").body).to eq("abc")
       end
 
       it "should return stubbed response even if query params have integer values" do
-        stub_request(:get, "www.example.com").with(:query => {"a" => 1}).to_return(:body => "abc")
+        stub_request(:get, "www.example.com").with(query: {"a" => 1}).to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?a=1").body).to eq("abc")
       end
 
       it "should return stubbed response even if request has non escaped params" do
-        stub_request(:get, "www.example.com/hello%2B/?#{ESCAPED_PARAMS}").to_return(:body => "abc")
+        stub_request(:get, "www.example.com/hello%2B/?#{ESCAPED_PARAMS}").to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/hello+/?#{NOT_ESCAPED_PARAMS}").body).to eq("abc")
       end
 
-      it "should return stubbed response for url with non utf query params", "ruby>1.9" => true do
+      it "should return stubbed response for url with non utf query params" do
         param = 'aäoöuü'.encode('iso-8859-1')
         param = CGI.escape(param)
-        stub_request(:get, "www.example.com/?#{param}").to_return(:body => "abc")
+        stub_request(:get, "www.example.com/?#{param}").to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?#{param}").body).to eq("abc")
       end
 
       it "should return stubbed response even if stub uri is declared as regexp and request params are escaped" do
-        stub_request(:get, /.*x=ab c.*/).to_return(:body => "abc")
+        stub_request(:get, /.*x=ab c.*/).to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/hello/?#{ESCAPED_PARAMS}").body).to eq("abc")
       end
 
@@ -34,8 +34,8 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         begin
           http_request(:get, "http://www.example.com/hello+/?#{NOT_ESCAPED_PARAMS}")
         rescue WebMock::NetConnectNotAllowedError => e
-          expect(e.message).to match /Unregistered request: GET http:\/\/www\.example\.com\/hello\+\/\?x=ab%20c&z='Stop!'%20said%20Fred%20m/m
-          expect(e.message).to match /stub_request\(:get, "http:\/\/www\.example\.com\/hello\+\/\?x=ab%20c&z='Stop!'%20said%20Fred%20m"\)/m
+          expect(e.message).to match(/Unregistered request: GET http:\/\/www\.example\.com\/hello\+\/\?x=ab%20c&z='Stop!'%20said%20Fred%20m/m)
+          expect(e.message).to match(/stub_request\(:get, "http:\/\/www\.example\.com\/hello\+\/\?x=ab%20c&z='Stop!'%20said%20Fred%20m"\)/m)
         end
 
         stub_request(:get, "http://www.example.com/hello+/?x=ab%20c&z='Stop!'%20said%20Fred%20m")
@@ -45,22 +45,22 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
     describe "based on query params" do
       it "should return stubbed response when stub declares query params as a hash" do
-        stub_request(:get, "www.example.com").with(:query => {"a" => ["b x", "c d"]}).to_return(:body => "abc")
+        stub_request(:get, "www.example.com").with(query: {"a" => ["b x", "c d"]}).to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?a[]=b+x&a[]=c%20d").body).to eq("abc")
       end
 
       it "should return stubbed response when stub declares query params as a hash" do
-        stub_request(:get, "www.example.com").with(:query => "a[]=b&a[]=c").to_return(:body => "abc")
+        stub_request(:get, "www.example.com").with(query: "a[]=b&a[]=c").to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?a[]=b&a[]=c").body).to eq("abc")
       end
 
       it "should return stubbed response when stub declares query params both in uri and as a hash" do
-        stub_request(:get, "www.example.com/?x=3").with(:query => {"a" => ["b", "c"]}).to_return(:body => "abc")
+        stub_request(:get, "www.example.com/?x=3").with(query: {"a" => ["b", "c"]}).to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?x=3&a[]=b&a[]=c").body).to eq("abc")
       end
 
       it "should return stubbed response when stub expects only part of query params" do
-        stub_request(:get, "www.example.com").with(:query => hash_including({"a" => ["b", "c"]})).to_return(:body => "abc")
+        stub_request(:get, "www.example.com").with(query: hash_including({"a" => ["b", "c"]})).to_return(body: "abc")
         expect(http_request(:get, "http://www.example.com/?a[]=b&a[]=c&b=1").body).to eq("abc")
       end
     end
@@ -88,38 +88,38 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
     describe "based on body" do
       it "should match requests if body is the same" do
-        stub_request(:post, "www.example.com").with(:body => "abc")
+        stub_request(:post, "www.example.com").with(body: "abc")
         expect(http_request(
           :post, "http://www.example.com/",
-        :body => "abc").status).to eq("200")
+        body: "abc").status).to eq("200")
       end
 
       it "should match requests if body is not set in the stub" do
         stub_request(:post, "www.example.com")
         expect(http_request(
           :post, "http://www.example.com/",
-        :body => "abc").status).to eq("200")
+        body: "abc").status).to eq("200")
       end
 
       it "should not match requests if body is different" do
-        stub_request(:post, "www.example.com").with(:body => "abc")
+        stub_request(:post, "www.example.com").with(body: "abc")
         expect {
-          http_request(:post, "http://www.example.com/", :body => "def")
+          http_request(:post, "http://www.example.com/", body: "def")
         }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: POST http://www.example.com/ with body 'def'))
       end
 
       describe "with regular expressions" do
         it "should match requests if body matches regexp" do
-          stub_request(:post, "www.example.com").with(:body => /\d+abc$/)
+          stub_request(:post, "www.example.com").with(body: /\d+abc$/)
           expect(http_request(
             :post, "http://www.example.com/",
-          :body => "123abc").status).to eq("200")
+          body: "123abc").status).to eq("200")
         end
 
         it "should not match requests if body doesn't match regexp" do
-          stub_request(:post, "www.example.com").with(:body => /^abc/)
+          stub_request(:post, "www.example.com").with(body: /^abc/)
           expect {
-            http_request(:post, "http://www.example.com/", :body => "xabc")
+            http_request(:post, "http://www.example.com/", body: "xabc")
           }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: POST http://www.example.com/ with body 'xabc'))
         end
       end
@@ -127,27 +127,27 @@ shared_examples_for "stubbing requests" do |*adapter_info|
       describe "when body is declared as a hash" do
         before(:each) do
           stub_request(:post, "www.example.com").
-            with(:body => {:a => '1', :b => 'five x', 'c' => {'d' => ['e', 'f']} })
+            with(body: {:a => '1', :b => 'five x', 'c' => {'d' => ['e', 'f']} })
         end
 
         describe "for request with url encoded body" do
           it "should match request if hash matches body" do
             expect(http_request(
               :post, "http://www.example.com/",
-            :body => 'a=1&c[d][]=e&c[d][]=f&b=five+x').status).to eq("200")
+            body: 'a=1&c[d][]=e&c[d][]=f&b=five+x').status).to eq("200")
           end
 
           it "should match request if hash matches body in different order of params" do
             expect(http_request(
               :post, "http://www.example.com/",
-            :body => 'a=1&c[d][]=e&b=five+x&c[d][]=f').status).to eq("200")
+            body: 'a=1&c[d][]=e&b=five+x&c[d][]=f').status).to eq("200")
           end
 
           it "should not match if hash doesn't match url encoded body" do
             expect {
               http_request(
                 :post, "http://www.example.com/",
-              :body => 'c[d][]=f&a=1&c[d][]=e')
+              body: 'c[d][]=f&a=1&c[d][]=e')
             }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: POST http://www.example.com/ with body 'c\[d\]\[\]=f&a=1&c\[d\]\[\]=e'))
           end
         end
@@ -156,31 +156,31 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         describe "for request with json body and content type is set to json" do
           it "should match if hash matches body" do
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/json'},
-            :body => "{\"a\":\"1\",\"c\":{\"d\":[\"e\",\"f\"]},\"b\":\"five x\"}").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"a\":\"1\",\"c\":{\"d\":[\"e\",\"f\"]},\"b\":\"five x\"}").status).to eq("200")
           end
 
           it "should match if hash matches body in different form" do
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/json'},
-            :body => "{\"a\":\"1\",\"b\":\"five x\",\"c\":{\"d\":[\"e\",\"f\"]}}").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"a\":\"1\",\"b\":\"five x\",\"c\":{\"d\":[\"e\",\"f\"]}}").status).to eq("200")
           end
 
           it "should match if hash contains date string" do #Crack creates date object
             WebMock.reset!
             stub_request(:post, "www.example.com").
-              with(:body => {"foo" => "2010-01-01"})
+              with(body: {"foo" => "2010-01-01"})
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/json'},
-            :body => "{\"foo\":\"2010-01-01\"}").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"foo\":\"2010-01-01\"}").status).to eq("200")
           end
 
           it "should match if any of the strings have spaces" do
             WebMock.reset!
-            stub_request(:post, "www.example.com").with(:body => {"foo" => "a b c"})
+            stub_request(:post, "www.example.com").with(body: {"foo" => "a b c"})
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/json'},
-            :body => "{\"foo\":\"a b c\"}").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+            body: "{\"foo\":\"a b c\"}").status).to eq("200")
           end
         end
 
@@ -188,43 +188,43 @@ shared_examples_for "stubbing requests" do |*adapter_info|
           before(:each) do
             WebMock.reset!
             stub_request(:post, "www.example.com").
-              with(:body => { "opt" => {:a => '1', :b => 'five', 'c' => {'d' => ['e', 'f']} }})
+              with(body: { "opt" => {:a => '1', :b => 'five', 'c' => {'d' => ['e', 'f']} }})
           end
 
           it "should match if hash matches body" do
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/xml'},
-            :body => "<opt a=\"1\" b=\"five\">\n  <c>\n    <d>e</d>\n    <d>f</d>\n  </c>\n</opt>\n").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/xml'},
+            body: "<opt a=\"1\" b=\"five\">\n  <c>\n    <d>e</d>\n    <d>f</d>\n  </c>\n</opt>\n").status).to eq("200")
           end
 
           it "should match if hash matches body in different form" do
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/xml'},
-            :body => "<opt b=\"five\" a=\"1\">\n  <c>\n    <d>e</d>\n    <d>f</d>\n  </c>\n</opt>\n").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/xml'},
+            body: "<opt b=\"five\" a=\"1\">\n  <c>\n    <d>e</d>\n    <d>f</d>\n  </c>\n</opt>\n").status).to eq("200")
           end
 
           it "should match if hash contains date string" do #Crack creates date object
             WebMock.reset!
             stub_request(:post, "www.example.com").
-              with(:body => {"opt" => {"foo" => "2010-01-01"}})
+              with(body: {"opt" => {"foo" => "2010-01-01"}})
             expect(http_request(
-              :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/xml'},
-            :body => "<opt foo=\"2010-01-01\">\n</opt>\n").status).to eq("200")
+              :post, "http://www.example.com/", headers: {'Content-Type' => 'application/xml'},
+            body: "<opt foo=\"2010-01-01\">\n</opt>\n").status).to eq("200")
           end
         end
       end
 
       describe "when body is declared as partial hash matcher" do
         subject(:request) { http_request( :post, "http://www.example.com/",
-                                :body => 'a=1&c[d][]=e&c[d][]=f&b=five') }
+                                body: 'a=1&c[d][]=e&c[d][]=f&b=five') }
 
         subject(:wrong_request) { http_request(:post, "http://www.example.com/",
-                                      :body => 'c[d][]=f&a=1&c[d][]=e').status }
+                                      body: 'c[d][]=f&a=1&c[d][]=e').status }
 
         describe "when using 'RSpec:Mocks::ArgumentMatchers#hash_including'" do
           before(:each) do
             stub_request(:post, "www.example.com").
-              with(:body => hash_including(:a, :c => {'d' => ['e', 'f']} ))
+              with(body: hash_including(:a, c: {'d' => ['e', 'f']} ))
           end
 
           describe "for request with url encoded body" do
@@ -233,15 +233,15 @@ shared_examples_for "stubbing requests" do |*adapter_info|
             end
 
             it "should not match if hash doesn't match url encoded body" do
-              expect { wrong_request }.to raise_error
+              expect { wrong_request }.to raise_error(WebMock::NetConnectNotAllowedError)
             end
           end
 
           describe "for request with json body and content type is set to json" do
             it "should match if hash matches body" do
               expect(http_request(
-                :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/json'},
-              :body => "{\"a\":\"1\",\"c\":{\"d\":[\"e\",\"f\"]},\"b\":\"five\"}").status).to eq("200")
+                :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+              body: "{\"a\":\"1\",\"c\":{\"d\":[\"e\",\"f\"]},\"b\":\"five\"}").status).to eq("200")
             end
           end
         end
@@ -249,7 +249,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         describe "when using 'WebMock::API#hash_including'" do
           before(:each) do
             stub_request(:post, "www.example.com").
-              with(:body => WebMock::API.hash_including(:a, :c => {'d' => ['e', 'f']} ))
+              with(body: WebMock::API.hash_including(:a, c: {'d' => ['e', 'f']} ))
           end
 
           describe "for request with url encoded body" do
@@ -258,15 +258,15 @@ shared_examples_for "stubbing requests" do |*adapter_info|
             end
 
             it "should not match if hash doesn't match url encoded body" do
-              expect { wrong_request }.to raise_error
+              expect { wrong_request }.to raise_error(WebMock::NetConnectNotAllowedError)
             end
           end
 
           describe "for request with json body and content type is set to json" do
             it "should match if hash matches body" do
               expect(http_request(
-                :post, "http://www.example.com/", :headers => {'Content-Type' => 'application/json'},
-              :body => "{\"a\":\"1\",\"c\":{\"d\":[\"e\",\"f\"]},\"b\":\"five\"}").status).to eq("200")
+                :post, "http://www.example.com/", headers: {'Content-Type' => 'application/json'},
+              body: "{\"a\":\"1\",\"c\":{\"d\":[\"e\",\"f\"]},\"b\":\"five\"}").status).to eq("200")
             end
           end
         end
@@ -276,41 +276,41 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
     describe "based on headers" do
       it "should match requests if headers are the same" do
-        stub_request(:get, "www.example.com").with(:headers => SAMPLE_HEADERS )
+        stub_request(:get, "www.example.com").with(headers: SAMPLE_HEADERS )
         expect(http_request(
           :get, "http://www.example.com/",
-        :headers => SAMPLE_HEADERS).status).to eq("200")
+        headers: SAMPLE_HEADERS).status).to eq("200")
       end
 
       it "should match requests if headers are the same and declared as array" do
-        stub_request(:get, "www.example.com").with(:headers => {"a" => ["b"]} )
+        stub_request(:get, "www.example.com").with(headers: {"a" => ["b"]} )
         expect(http_request(
           :get, "http://www.example.com/",
-        :headers => {"a" => "b"}).status).to eq("200")
+        headers: {"a" => "b"}).status).to eq("200")
       end
 
       describe "when multiple headers with the same key are used" do
         it "should match requests if headers are the same" do
-          stub_request(:get, "www.example.com").with(:headers => {"a" => ["b", "c"]} )
+          stub_request(:get, "www.example.com").with(headers: {"a" => ["b", "c"]} )
           expect(http_request(
             :get, "http://www.example.com/",
-          :headers => {"a" => ["b", "c"]}).status).to eq("200")
+          headers: {"a" => ["b", "c"]}).status).to eq("200")
         end
 
         it "should match requests if headers are the same  but in different order" do
-          stub_request(:get, "www.example.com").with(:headers => {"a" => ["b", "c"]} )
+          stub_request(:get, "www.example.com").with(headers: {"a" => ["b", "c"]} )
           expect(http_request(
             :get, "http://www.example.com/",
-          :headers => {"a" => ["c", "b"]}).status).to eq("200")
+          headers: {"a" => ["c", "b"]}).status).to eq("200")
         end
 
         it "should not match requests if headers are different" do
-          stub_request(:get, "www.example.com").with(:headers => {"a" => ["b", "c"]})
+          stub_request(:get, "www.example.com").with(headers: {"a" => ["b", "c"]})
 
           expect {
             http_request(
               :get, "http://www.example.com/",
-            :headers => {"a" => ["b", "d"]})
+            headers: {"a" => ["b", "d"]})
           }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
         end
       end
@@ -319,50 +319,50 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         stub_request(:get, "www.example.com")
         expect(http_request(
           :get, "http://www.example.com/",
-        :headers => SAMPLE_HEADERS).status).to eq("200")
+        headers: SAMPLE_HEADERS).status).to eq("200")
       end
 
       it "should not match requests if headers are different" do
-        stub_request(:get, "www.example.com").with(:headers => SAMPLE_HEADERS)
+        stub_request(:get, "www.example.com").with(headers: SAMPLE_HEADERS)
 
         expect {
           http_request(
             :get, "http://www.example.com/",
-          :headers => { 'Content-Length' => '9999'})
+          headers: { 'Content-Length' => '9999'})
         }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
       end
 
       it "should not match if accept header is different" do
         stub_request(:get, "www.example.com").
-          with(:headers => { 'Accept' => 'application/json'})
+          with(headers: { 'Accept' => 'application/json'})
         expect {
           http_request(
             :get, "http://www.example.com/",
-          :headers => { 'Accept' => 'application/xml'})
+          headers: { 'Accept' => 'application/xml'})
         }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
       end
 
       describe "declared as regular expressions" do
         it "should match requests if header values match regular expression" do
-          stub_request(:get, "www.example.com").with(:headers => { :some_header => /^MyAppName$/ })
+          stub_request(:get, "www.example.com").with(headers: { some_header: /^MyAppName$/ })
           expect(http_request(
             :get, "http://www.example.com/",
-          :headers => { 'some-header' => 'MyAppName' }).status).to eq("200")
+          headers: { 'some-header' => 'MyAppName' }).status).to eq("200")
         end
 
         it "should not match requests if headers values do not match regular expression" do
-          stub_request(:get, "www.example.com").with(:headers => { :some_header => /^MyAppName$/ })
+          stub_request(:get, "www.example.com").with(headers: { some_header: /^MyAppName$/ })
 
           expect {
             http_request(
               :get, "http://www.example.com/",
-            :headers => { 'some-header' => 'xMyAppName' })
+            headers: { 'some-header' => 'xMyAppName' })
           }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
         end
       end
     end
 
-    describe "when stubbing request with basic authentication", :unless => (adapter_info.include?(:no_url_auth)) do
+    describe "when stubbing request with userinfo in url", unless: (adapter_info.include?(:no_url_auth)) do
       it "should match if credentials are the same" do
         stub_request(:get, "user:pass@www.example.com")
         expect(http_request(:get, "http://user:pass@www.example.com/").status).to eq("200")
@@ -388,6 +388,61 @@ shared_examples_for "stubbing requests" do |*adapter_info|
           expect(http_request(:get, "http://user:pazz@www.example.com/").status).to eq("200")
         }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://user:pazz@www.example.com/))
       end
+
+      it "should not match if request has credentials provided in basic authentication herader" do
+        stub_request(:get, "user:pass@www.example.com")
+        expect {
+          expect(http_request(:get, "http://www.example.com/", basic_auth: ['user', 'pass']).status).to eq("200")
+        }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
+      end
+    end
+
+    describe "when stubbing request with basic authentication header" do
+      it "should match if credentials are the same" do
+        stub_request(:get, "www.example.com").with(basic_auth: ['user', 'pass'])
+        expect(http_request(:get, "http://www.example.com/", basic_auth: ['user', 'pass']).status).to eq("200")
+      end
+
+      it "should match if credentials are the same and encode to more than one line" do
+        stub_request(:get, "www.example.com").with(basic_auth: ['user' * 5, 'pass' * 5])
+        expect(http_request(:get, "http://www.example.com/", basic_auth: ['user' * 5, 'pass' * 5]).status).to eq("200")
+      end
+
+      it "should match if credentials are the same and were provided directly as authentication headers in request" do
+        stub_request(:get, "www.example.com").with(basic_auth: ['user', 'pass'])
+        expect(http_request(:get, "http://www.example.com/", headers: {'Authorization'=>'Basic dXNlcjpwYXNz'}).status).to eq("200")
+      end
+
+      it "should match if credentials are the same and have been declared in the stub as encoded header" do
+        stub_request(:get, "www.example.com").with(headers: {'Authorization'=>'Basic dXNlcjpwYXNz'})
+        expect(http_request(:get, "http://www.example.com/", basic_auth: ['user', 'pass']).status).to eq("200")
+      end
+
+      it "should not match if credentials are different" do
+        stub_request(:get, "www.example.com").with(basic_auth: ['user', 'pass'])
+        expect {
+          expect(http_request(:get, "http://www.example.com/", basic_auth: ['user', 'pazz']).status).to eq("200")
+        }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/ with headers))
+      end
+
+      it "should not match if credentials are stubbed but not provided in the request" do
+        stub_request(:get, "www.example.com").with(basic_auth: ['user', 'pass'])
+        expect {
+          expect(http_request(:get, "http://www.example.com/").status).to eq("200")
+        }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://www.example.com/))
+      end
+
+      it "should match if credentials are not stubbed but exist in the request" do
+        stub_request(:get, "www.example.com")
+        expect(http_request(:get, "http://www.example.com/", basic_auth: ['user', 'pass']).status).to eq("200")
+      end
+
+      it "should not match if request has credentials provides in userinfo", unless: (adapter_info.include?(:no_url_auth)) do
+        stub_request(:get, "www.example.com").with(basic_auth: ['user', 'pass'])
+        expect {
+          expect(http_request(:get, "http://user:pass@www.example.com/").status).to eq("200")
+        }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: GET http://user:pass@www.example.com/))
+      end
     end
 
     describe "when stubbing request with a global hook" do
@@ -397,7 +452,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
       it 'returns the response returned by the hook' do
         WebMock.globally_stub_request do |request|
-          { :body => "global stub body" }
+          { body: "global stub body" }
         end
 
         expect(http_request(:get, "http://www.example.com/").body).to eq("global stub body")
@@ -405,7 +460,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
       it 'does not get cleared when a user calls WebMock.reset!' do
         WebMock.globally_stub_request do |request|
-          { :body => "global stub body" }
+          { body: "global stub body" }
         end
         WebMock.reset!
         expect(http_request(:get, "http://www.example.com/").body).to eq("global stub body")
@@ -422,7 +477,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         passed_request = nil
         WebMock.globally_stub_request do |request|
           passed_request = request
-          { :body => "global stub body" }
+          { body: "global stub body" }
         end
 
         http_request(:get, "http://www.example.com:456/bar")
@@ -433,7 +488,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         call_count = 0
         WebMock.globally_stub_request do |request|
           call_count += 1
-          { :body => "global stub body" }
+          { body: "global stub body" }
         end
         http_request(:get, "http://www.example.com/")
         expect(call_count).to eq(1)
@@ -448,7 +503,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
 
         WebMock.globally_stub_request do |request|
           stub_invocation_order << :hash_stub
-          { :body => "global stub body" }
+          { body: "global stub body" }
         end
 
         expect(http_request(:get, "http://www.example.com/").body).to eq("global stub body")
@@ -458,7 +513,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
       [:before, :after].each do |before_or_after|
         context "when there is also a non-global registered stub #{before_or_after} the global stub" do
           def stub_non_globally
-            stub_request(:get, "www.example.com").to_return(:body => 'non-global stub body')
+            stub_request(:get, "www.example.com").to_return(body: 'non-global stub body')
           end
 
           define_method :register_stubs do |block|
@@ -468,7 +523,7 @@ shared_examples_for "stubbing requests" do |*adapter_info|
           end
 
           it 'uses the response from the global stub if the block returns a non-nil value' do
-            register_stubs(lambda { |req| { :body => 'global stub body' } })
+            register_stubs(lambda { |req| { body: 'global stub body' } })
             expect(http_request(:get, "http://www.example.com/").body).to eq("global stub body")
           end
 
@@ -497,9 +552,9 @@ shared_examples_for "stubbing requests" do |*adapter_info|
         stub_request(:post, "www.example.com").with { |request| request.body == "wadus" }
         expect(http_request(
           :post, "http://www.example.com/",
-        :body => "wadus").status).to eq("200")
+        body: "wadus").status).to eq("200")
         expect {
-          http_request(:post, "http://www.example.com/", :body => "jander")
+          http_request(:post, "http://www.example.com/", body: "jander")
         }.to raise_error(WebMock::NetConnectNotAllowedError, %r(Real HTTP connections are disabled. Unregistered request: POST http://www.example.com/ with body 'jander'))
       end
 
