@@ -22,7 +22,7 @@ unless RUBY_PLATFORM =~ /java/
 
       describe "supposed response fields" do
         it "present" do
-          stub_request(:get, "http://www.example.com").to_return(:headers => {'X-Test' => '1'})
+          stub_request(:get, "http://www.example.com").to_return(headers: {'X-Test' => '1'})
           response = Typhoeus.get("http://www.example.com")
           expect(response.code).not_to be_nil
           expect(response.status_message).not_to be_nil
@@ -34,21 +34,21 @@ unless RUBY_PLATFORM =~ /java/
 
       describe "when params are used" do
         it "should take into account params for POST request" do
-          stub_request(:post, "www.example.com/?hello=world").with(:query => {:hello => 'world'})
-          request = Typhoeus::Request.new("http://www.example.com", :method => :post, :params => {:hello => 'world'})
+          stub_request(:post, "www.example.com/?hello=world").with(query: {hello: 'world'})
+          request = Typhoeus::Request.new("http://www.example.com", method: :post, params: {hello: 'world'})
           hydra.queue(request)
           hydra.run
         end
 
         it "should take into account body for POST request" do
-          stub_request(:post, "www.example.com").with(:body => {:hello => 'world'})
-          response = Typhoeus.post("http://www.example.com", :method => :post, :body => {:hello => 'world'})
+          stub_request(:post, "www.example.com").with(body: {hello: 'world'})
+          response = Typhoeus.post("http://www.example.com", method: :post, body: {hello: 'world'})
           expect(response.code).to eq(200)
         end
 
         it "should take into account params for GET request" do
           stub_request(:get, "http://www.example.com/?hello=world").to_return({})
-          request = Typhoeus::Request.new("http://www.example.com/?hello=world", :method => :get)
+          request = Typhoeus::Request.new("http://www.example.com/?hello=world", method: :get)
           hydra.queue(request)
           hydra.run
         end
@@ -58,7 +58,7 @@ unless RUBY_PLATFORM =~ /java/
         it "should support native typhoeus timeouts" do
           stub_request(:any, "example.com").to_timeout
 
-          request = Typhoeus::Request.new("http://example.com", :method => :get)
+          request = Typhoeus::Request.new("http://example.com", method: :get)
           hydra.queue(request)
           hydra.run
 
@@ -73,7 +73,7 @@ unless RUBY_PLATFORM =~ /java/
 
         it "should call on_complete with 2xx response" do
           body = "on_success fired"
-          stub_request(:any, "example.com").to_return(:body => body)
+          stub_request(:any, "example.com").to_return(body: body)
 
           test = nil
           Typhoeus.on_complete do |c|
@@ -86,7 +86,7 @@ unless RUBY_PLATFORM =~ /java/
 
         it "should call on_complete with 5xx response" do
           response_code = 599
-          stub_request(:any, "example.com").to_return(:status => [response_code, "Server On Fire"])
+          stub_request(:any, "example.com").to_return(status: [response_code, "Server On Fire"])
 
           test = nil
           Typhoeus.on_complete do |c|
@@ -99,13 +99,13 @@ unless RUBY_PLATFORM =~ /java/
 
         it "should call on_body with 2xx response" do
           body = "on_body fired"
-          stub_request(:any, "example.com").to_return(:body => body)
+          stub_request(:any, "example.com").to_return(body: body)
 
           test_body = nil
           test_complete = nil
           skip("This test requires a newer version of Typhoeus") unless @request.respond_to?(:on_body)
-          @request.on_body do |body, response|
-            test_body = body
+          @request.on_body do |body_chunk, response|
+            test_body = body_chunk
           end
           @request.on_complete do |response|
             test_complete = response.body
@@ -118,7 +118,7 @@ unless RUBY_PLATFORM =~ /java/
 
         it "should call on_headers with 2xx response" do
           body = "on_headers fired"
-          stub_request(:any, "example.com").to_return(:body => body, :headers => {'X-Test' => '1'})
+          stub_request(:any, "example.com").to_return(body: body, headers: {'X-Test' => '1'})
 
           test_headers = nil
           skip("This test requires a newer version of Typhoeus") unless @request.respond_to?(:on_headers)
