@@ -6,7 +6,7 @@ describe WebMock::Util::QueryMapper do
   context '#query_to_values' do
     it 'should raise on invalid notation' do
       query = 'a=&b=c'
-      expect { subject.query_to_values(query, {:notation => 'foo'}) }.to raise_error(
+      expect { subject.query_to_values(query, {notation: 'foo'}) }.to raise_error(
         ArgumentError,
         'Invalid notation. Must be one of: [:flat, :dot, :subscript, :flat_array].'
       )
@@ -48,6 +48,28 @@ describe WebMock::Util::QueryMapper do
       expect(hsh['a'][0]['b'][0]['c'][0]['d'][0]).to eq('1')
       expect(hsh['a'][0]['b'][0]['c'][0]['d'][1]['e']).to eq('2')
     end
+
+    it "should parse nested repeated correctly" do
+      query = "a[][b][]=one&a[][b][]=two"
+      hsh = subject.query_to_values(query)
+      expect(hsh['a']).to be_a(Array)
+      expect(hsh['a'][0]).to eq({"b" => ['one']})
+      expect(hsh['a'][1]).to eq({"b" => ['two']})
+    end
+
+    it "should parse nested non-repeated correctly" do
+      query = "a[][b][]=one&a[][c][]=two"
+      hsh = subject.query_to_values(query)
+      expect(hsh['a']).to be_a(Array)
+      expect(hsh['a'][0]['b']).to eq(['one'])
+      expect(hsh['a'][0]['c']).to eq(['two'])
+    end
+
+    it 'should not attempt to mutate its query argument' do
+      query = "a=foo".freeze
+      hsh = subject.query_to_values(query)
+      expect(hsh['a']).to eq('foo')
+    end
   end
 
   context '#to_query' do
@@ -61,7 +83,7 @@ describe WebMock::Util::QueryMapper do
       expect(subject.to_query('a', {'key' => 'value'})).to eq('a[key]=value')
     end
     it 'should transform hash value with keys that are symbols' do
-      expect(subject.to_query('a', {:key => 'value'})).to eq('a[key]=value')
+      expect(subject.to_query('a', {key: 'value'})).to eq('a[key]=value')
     end
     it 'should transform array value' do
       expect(subject.to_query('a', ['b', 'c'])).to eq('a[0]=b&a[1]=c')
@@ -106,9 +128,16 @@ describe WebMock::Util::QueryMapper do
     expect(subject.query_to_values query).to eq values
   end
 
-  it 'converts complex nested values, vice versa' do
+  it 'converts complex nested hashes, vice versa' do
     query = "one%5B%5D[foo]=bar&one%5B%5D[zoo]=car" # one[][foo]=bar&one[][zoo]=car
-    values = {"one" => [{"foo" => "bar"}, {"zoo" => "car"}]}
+    values = {"one" => [{"foo" => "bar", "zoo" => "car"}]}
+    expect(subject.values_to_query values).to eq query
+    expect(subject.query_to_values query).to eq values
+  end
+
+  it 'converts complex nested array of hashes, vice versa' do
+    query = "one%5B%5D[foo]=bar&one%5B%5D[foo]=bar&one%5B%5D[zoo]=car" # one[][foo]=bar&one[][foo]=bar&one[][zoo]=car
+    values = {"one" => [{"foo" => "bar"}, {"foo" => "bar", "zoo" => "car"}]}
     expect(subject.values_to_query values).to eq query
     expect(subject.query_to_values query).to eq values
   end
